@@ -3,14 +3,14 @@ use warnings;
 
 package Code::Statistics::Metric;
 BEGIN {
-  $Code::Statistics::Metric::VERSION = '1.102360';
+  $Code::Statistics::Metric::VERSION = '1.102370';
 }
 
 # ABSTRACT: base class for Code::Statistic metrics
 
 use 5.004;
 
-use Module::Pluggable search_path => __PACKAGE__, sub_name => 'all';
+use Module::Pluggable search_path => __PACKAGE__, require => 1, sub_name => 'all';
 
 
 sub measure {
@@ -25,9 +25,22 @@ sub incompatible_with {
 }
 
 
-sub supports {
+sub force_support {
     my ( $class, $target ) = @_;
-    return 1;
+    return 0;
+}
+
+
+sub short_name {
+    my ( $class ) = @_;
+    $class =~ s/Code::Statistics::Metric:://;
+    return $class;
+}
+
+
+sub is_insignificant {
+    my ( $class ) = @_;
+    return 0;
 }
 
 1;
@@ -41,7 +54,7 @@ Code::Statistics::Metric - base class for Code::Statistic metrics
 
 =head1 VERSION
 
-version 1.102360
+version 1.102370
 
 =head2 measure
     Returns the metric of the given target.
@@ -56,14 +69,24 @@ version 1.102360
     identifiers after 'Code::Statistics::Target::'.
     Default is that all metrics are compatible with all targets.
 
-=head2 supports
-    Returns true if the given target is supported by this metric.
+=head2 force_support
+    Returns true if the given target is forcibly supported by this metric.
     Is called with the metric class name and a string representing the target
     identifiers after 'Code::Statistics::Target::'.
-    Default is that all metrics are compatible with all targets.
+    Default is that no forcing happens.
 
     Has higher precedence than 'incompatible_with' and should be used to
-    incompatibilities set by other targets.
+    override incompatibilities set by other targets.
+
+=head2 short_name
+    Allows a metric to return a short name, which can be used by shell report
+    builders for example.
+    Default is the class name, with 'Code::Statistics::Metric::' stripped out.
+    Override to customize.
+
+=head2 is_insignificant
+    Returns true if the metric is considered statistically insignificant.
+    Default is false.
 
 =head1 AUTHOR
 
